Crate wgpu_shader_checker
wgpu_
shader_
checker
0.2.0
All Items
Crate Items
Macros
Crate
wgpu_
shader_
checker
Macros

include_
wgsl
Load WGSL source code from a file at compile time. If the file can not be compiled it will throw a compilation error.